@@ -308,7 +308,7 @@ enter_loop(Mod, Options, StateName, StateData, Timeout) ->
 enter_loop(Mod, Options, StateName, StateData, ServerName, Timeout) ->
     Name = get_proc_name(ServerName),
     Parent = get_parent(),
-    Debug = gen:debug_options(Options),
+    Debug = debug_options(Options),
     Limits = limit_options(Options),
     Queue = queue:new(),
     QueueLen = 0,
@@ -370,7 +370,7 @@ init_it(Starter, self, Name, Mod, Args, Options) ->
     init_it(Starter, self(), Name, Mod, Args, Options);
 init_it(Starter, Parent, Name0, Mod, Args, Options) ->
     Name = name(Name0),
-    Debug = gen:debug_options(Options),
+    Debug = debug_options(Options),
     Limits = limit_options(Options),
     Queue = queue:new(),
     QueueLen = 0,
@@ -905,3 +905,16 @@ rpc_call(Node, Mod, Fun, Args, Timeout) ->
 		    {badrpc, timeout}
 	    end
     end.
+
+opt(Op, [{Op, Value}|_]) ->
+    {ok, Value};
+opt(Op, [_|Options]) ->
+    opt(Op, Options);
+opt(_, []) ->
+    false.
+
+debug_options(Opts) ->
+    case opt(debug, Opts) of
+	{ok, Options} -> sys:debug_options(Options);
+	_ -> []
+    end.
